@@ -3,16 +3,15 @@
 from __future__ import annotations
 
 import pathlib
+import tomllib
 import webbrowser
 from typing import Any
 from urllib.parse import urlencode
 
-import tomli
-
 
 def project_project(cwd: pathlib.Path) -> dict[str, Any]:
     """Read `pyproject.toml` project."""
-    pyproject = tomli.loads(
+    pyproject = tomllib.loads(
         cwd.joinpath(
             "pyproject.toml",
         ).read_text(encoding="utf-8"),
